@@ -10,8 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
-
 from testtools.testcase import skip
 from toscaparser.common import exception
 from toscaparser.dataentity import DataEntity
@@ -343,20 +341,17 @@ class DataTypeTest(TestCase):
                          error.__str__())
 
     def test_datatype_in_current_template(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/datatypes/test_custom_datatypes_in_current_template.yaml")
         self.assertIsNotNone(ToscaTemplate(tpl_path))
 
     def test_datatype_in_template_positive(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/datatypes/test_custom_datatypes_positive.yaml")
         self.assertIsNotNone(ToscaTemplate(tpl_path))
 
     def test_datatype_in_template_invalid_value(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/datatypes/test_custom_datatypes_value_error.yaml")
         self.assertRaises(exception.ValidationError, ToscaTemplate, tpl_path)
         exception.ExceptionCollector.assertExceptionMessage(
@@ -364,8 +359,7 @@ class DataTypeTest(TestCase):
             _('"[\'1 foo street\', \'9 bar avenue\']" is not a map.'))
 
     def test_datatype_in_template_nested_datatype_error(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/datatypes/test_custom_datatypes_nested_datatype_error.yaml")
         self.assertRaises(exception.ValidationError, ToscaTemplate, tpl_path)
         exception.ExceptionCollector.assertExceptionMessage(
