@@ -21,8 +21,7 @@ from toscaparser.utils.gettextutils import _
 
 class IntrinsicFunctionsTest(TestCase):
 
-    tosca_tpl = os.path.join(
-        os.path.dirname(os.path.abspath(__file__)),
+    tosca_tpl = TestCase.test_sample(
         "data/tosca_single_instance_wordpress.yaml")
     params = {'db_name': 'my_wordpress', 'db_user': 'my_db_user',
               'db_root_pwd': '12345678'}
@@ -120,8 +119,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual(dbms_root_password.result(), '12345678')
 
     def test_get_property_with_host(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/functions/test_get_property_with_host.yaml")
         mysql_database = self._get_node('mysql_database',
                                         ToscaTemplate(tosca_tpl,
@@ -139,8 +137,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual(1, result)
 
     def test_get_property_with_nested_params(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/functions/tosca_nested_property_names_indexes.yaml")
         webserver = self._get_node('wordpress',
                                    ToscaTemplate(tosca_tpl,
@@ -155,8 +152,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual(3, wp_list_prop.result())
 
     def test_get_property_with_capabilties_inheritance(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/functions/test_capabilties_inheritance.yaml")
         some_node = self._get_node('some_node',
                                    ToscaTemplate(tosca_tpl,
@@ -168,8 +164,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual('someval', some_input.result())
 
     def test_get_property_source_target_keywords(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/functions/test_get_property_source_target_keywords.yaml")
         tosca = ToscaTemplate(tosca_tpl,
                               parsed_params={'db_root_pwd': '1234'})
@@ -189,8 +184,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual(3306, source_port.result())
 
     def test_get_prop_cap_host(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/functions/test_get_prop_cap_host.yaml")
         some_node = self._get_node('some_node',
                                    ToscaTemplate(tosca_tpl))
@@ -199,8 +193,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual('someval', some_prop.value.result())
 
     def test_get_prop_cap_bool(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/functions/test_get_prop_cap_bool.yaml")
         some_node = self._get_node('software',
                                    ToscaTemplate(tosca_tpl))
@@ -213,9 +206,7 @@ class GetAttributeTest(TestCase):
 
     def _load_template(self, filename):
         return ToscaTemplate(os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            'data',
-            filename),
+            TestCase.test_sample('data'), filename),
             parsed_params={'db_root_pwd': '1234'})
 
     def _get_operation(self, interfaces, operation):
@@ -312,8 +303,7 @@ class GetAttributeTest(TestCase):
               'Unexpected attribute/index value "0"'))
 
     def test_get_attribute_source_target_keywords(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/functions/test_get_attribute_source_target_keywords.yaml")
         tosca = ToscaTemplate(tosca_tpl,
                               parsed_params={'db_root_pwd': '12345678'})
@@ -342,13 +332,19 @@ class GetAttributeTest(TestCase):
         self.assertIsNotNone(self._load_template(
             'functions/test_container_cap_child.yaml'))
 
+    def test_get_attribute_custom_data_type(self):
+        self.assertIsNotNone(self._load_template(
+            'functions/test_get_attribute_custom_data_type.yaml'))
+
+    def test_get_attribute_neste_data_types(self):
+        self.assertIsNotNone(self._load_template(
+            'functions/test_get_attribute_nested_data_types.yaml'))
+
 
 class ConcatTest(TestCase):
 
     def _load_template(self, filename):
-        return ToscaTemplate(os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            filename))
+        return ToscaTemplate(TestCase.test_sample(filename))
 
     def test_validate_concat(self):
         tosca = self._load_template("data/functions/test_concat.yaml")
@@ -369,9 +365,7 @@ class ConcatTest(TestCase):
 class TokenTest(TestCase):
 
     def _load_template(self, filename):
-        return ToscaTemplate(os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            filename))
+        return ToscaTemplate(TestCase.test_sample(filename))
 
     def test_validate_token(self):
         tosca = self._load_template("data/functions/test_token.yaml")
