@@ -11,21 +11,26 @@
 #    under the License.
 
 import os
+import requests
 import shutil
+from unittest import mock
+import urllib
 import zipfile
 
 from toscaparser.common.exception import ExceptionCollector
 from toscaparser.common.exception import URLException
 from toscaparser.common.exception import ValidationError
 from toscaparser.prereq.csar import CSAR
+from toscaparser.tests.base import MockTestClass
 from toscaparser.tests.base import TestCase
 import toscaparser.utils
 from toscaparser.utils.gettextutils import _
+from toscaparser.utils.urlutils import UrlUtils
 
 
 class CSARPrereqTest(TestCase):
 
-    base_path = os.path.dirname(os.path.abspath(__file__))
+    base_path = TestCase.test_sample_root()
 
     def setUp(self):
         super(CSARPrereqTest, self).setUp()
@@ -46,9 +51,20 @@ class CSARPrereqTest(TestCase):
         error = self.assertRaises(ValidationError, csar.validate)
         self.assertEqual(_('"%s" is not a valid zip file.') % path, str(error))
 
-    def test_url_is_zip(self):
-        path = "https://github.com/openstack/tosca-parser/raw/master/" \
-               "toscaparser/tests/data/CSAR/csar_not_zip.zip"
+    @mock.patch.object(requests, 'get')
+    def test_url_is_zip(self, mock_requests_get):
+        path = "https://example.com/csar_not_zip.zip"
+
+        class TestResponse:
+            content: bytes
+
+        response = TestResponse()
+        file_path = TestCase.test_sample("data/CSAR/csar_not_zip.zip")
+
+        with open(file_path, 'br') as f:
+            response.content = f.read()
+
+        mock_requests_get.return_value = response
         csar = CSAR(path, False)
         error = self.assertRaises(ValidationError, csar.validate)
         self.assertEqual(_('"%s" is not a valid zip file.') % path, str(error))
@@ -167,9 +183,19 @@ class CSARPrereqTest(TestCase):
         self.assertTrue(csar.temp_dir is None or
                         not os.path.exists(csar.temp_dir))
 
-    def test_valid_csar_with_url_import_and_script(self):
+    @mock.patch.object(urllib.request, 'urlopen')
+    @mock.patch.object(UrlUtils, 'url_accessible')
+    def test_valid_csar_with_url_import_and_script(
+            self, mock_url_accessible, mock_urlopen):
         path = os.path.join(self.base_path, "data/CSAR/csar_wordpress_with_url"
                             "_import_and_script.zip")
+        mock_path = "https://example.com/wordpress.yaml"
+
+        mockclass = MockTestClass()
+        mockclass.comp_urldict = {mock_path: TestCase.test_sample(
+            "data/custom_types/wordpress.yaml")}
+        mock_urlopen.side_effect = mockclass.mock_urlopen_method
+        mock_url_accessible.return_value = True
         csar = CSAR(path)
         self.assertTrue(csar.validate())
         self.assertTrue(csar.temp_dir is None or
@@ -208,8 +234,7 @@ class CSARPrereqTest(TestCase):
     def test_csar_main_template(self):
         path = os.path.join(self.base_path, "data/CSAR/csar_hello_world.zip")
         csar = CSAR(path)
-        yaml_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                 "data/tosca_helloworld.yaml")
+        yaml_file = TestCase.test_sample("data/tosca_helloworld.yaml")
         expected_yaml = toscaparser.utils.yamlparser.load_yaml(yaml_file)
         self.assertEqual(expected_yaml, csar.get_main_template_yaml())
         self.assertTrue(csar.temp_dir is None or
@@ -239,8 +264,7 @@ class CSARPrereqTest(TestCase):
         path = os.path.join(self.base_path,
                             "data/CSAR/csar_root_level_yaml.zip")
         csar = CSAR(path)
-        yaml_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                 "data/CSAR/root_level_file.yaml")
+        yaml_file = TestCase.test_sample("data/CSAR/root_level_file.yaml")
         expected_yaml = toscaparser.utils.yamlparser.load_yaml(yaml_file)
         self.assertEqual(expected_yaml, csar.get_main_template_yaml())
         self.assertTrue(csar.temp_dir is None or
@@ -261,8 +285,7 @@ class CSARPrereqTest(TestCase):
                             "data/CSAR/csar_root_level_"
                             "yaml_and_tosca_metadata.zip")
         csar = CSAR(path)
-        yaml_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                 "data/CSAR/tosca_meta_file.yaml")
+        yaml_file = TestCase.test_sample("data/CSAR/tosca_meta_file.yaml")
         expected_yaml = toscaparser.utils.yamlparser.load_yaml(yaml_file)
         self.assertEqual(expected_yaml, csar.get_main_template_yaml())
         self.assertTrue(csar.temp_dir is None or
@@ -284,8 +307,8 @@ class CSARPrereqTest(TestCase):
             self.base_path,
             "data/CSAR/csar_valid_multilevel_imports_validation.zip")
         csar = CSAR(path)
-        yaml_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                 "data/CSAR/multi_level_imports_response.yaml")
+        yaml_file = TestCase.test_sample(
+            "data/CSAR/multi_level_imports_response.yaml")
         expected_yaml = toscaparser.utils.yamlparser.load_yaml(yaml_file)
         self.assertEqual(expected_yaml, csar.get_main_template_yaml())
         self.assertTrue(csar.temp_dir is None or
