@@ -10,7 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
+from unittest import mock
+import urllib
 
 from toscaparser.common import exception
 from toscaparser.imports import ImportsLoader
@@ -21,6 +22,7 @@ from toscaparser.policy import Policy
 from toscaparser.relationship_template import RelationshipTemplate
 from toscaparser.repositories import Repository
 from toscaparser.reservation import Reservation
+from toscaparser.tests.base import MockTestClass
 from toscaparser.tests.base import TestCase
 from toscaparser.topology_template import TopologyTemplate
 from toscaparser.tosca_template import ToscaTemplate
@@ -32,22 +34,19 @@ import toscaparser.utils.yamlparser
 class ToscaTemplateValidationTest(TestCase):
 
     def test_well_defined_template(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/tosca_single_instance_wordpress.yaml")
         params = {'db_name': 'my_wordpress', 'db_user': 'my_db_user',
                   'db_root_pwd': '12345678'}
         self.assertIsNotNone(ToscaTemplate(tpl_path, params))
 
     def test_custom_interface_allowed(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/interfaces/test_custom_interface_in_template.yaml")
         self.assertIsNotNone(ToscaTemplate(tpl_path))
 
     def test_custom_interface_invalid_operation(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/interfaces/test_custom_interface_invalid_operation.yaml")
         self.assertRaises(exception.ValidationError,
                           ToscaTemplate, tpl_path)
@@ -57,9 +56,44 @@ class ToscaTemplateValidationTest(TestCase):
               'contains unknown field "CustomOp4". '
               'Refer to the definition to verify valid values.'))
 
+    # Since 'operations' Keyname was defined in TOSCA1.3,
+    # test whether operation_definitions defined
+    # under 'operations' can be used.
+    def test_custom_interface_operations(self):
+        tpl_path = TestCase.test_sample(
+            "data/interfaces/test_custom_interface_operations.yaml")
+        tosca = ToscaTemplate(tpl_path)
+        op_names = tosca.tpl['interface_types'][
+            'tosca.interfaces.CustomInterface']['operations'].keys()
+        self.assertEqual('CustomOp', list(op_names)[0])
+        op_names = tosca.topology_template.custom_defs[
+            'tosca.interfaces.CustomInterface']['operations'].keys()
+        self.assertEqual('CustomOp', list(op_names)[0])
+        op_names = tosca.topology_template.nodetemplates[0].templates[
+            'customInterfaceTest']['interfaces']['CustomInterface'][
+                'operations'].keys()
+        self.assertEqual('CustomOp', list(op_names)[0])
+
+    # Since 'notifications' Keyname was defined in TOSCA1.3,
+    # test whether notification_definitions defined
+    # under 'notifications' can be used.
+    def test_custom_interface_notifications(self):
+        tpl_path = TestCase.test_sample(
+            "data/interfaces/test_custom_interface_notifications.yaml")
+        tosca = ToscaTemplate(tpl_path)
+        no_names = tosca.tpl['interface_types'][
+            'tosca.interfaces.CustomInterface']['notifications'].keys()
+        self.assertEqual('CustomNo', list(no_names)[0])
+        no_names = tosca.topology_template.custom_defs[
+            'tosca.interfaces.CustomInterface']['notifications'].keys()
+        self.assertEqual('CustomNo', list(no_names)[0])
+        no_names = tosca.topology_template.nodetemplates[0].templates[
+            'customInterfaceTest']['interfaces']['CustomInterface'][
+                'notifications'].keys()
+        self.assertEqual('CustomNo', list(no_names)[0])
+
     def test_first_level_sections(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/test_tosca_top_level_error1.yaml")
         self.assertRaises(exception.ValidationError, ToscaTemplate, tpl_path)
         exception.ExceptionCollector.assertExceptionMessage(
@@ -67,8 +101,7 @@ class ToscaTemplateValidationTest(TestCase):
             _('Template is missing required field '
               '"tosca_definitions_version".'))
 
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/test_tosca_top_level_error2.yaml")
         self.assertRaises(exception.ValidationError, ToscaTemplate, tpl_path)
         exception.ExceptionCollector.assertExceptionMessage(
@@ -77,9 +110,7 @@ class ToscaTemplateValidationTest(TestCase):
               'definition to verify valid values.'))
 
     def test_template_with_imports_validation(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "data/tosca_imports_validation.yaml")
+        tpl_path = TestCase.test_sample("data/tosca_imports_validation.yaml")
         self.assertRaises(exception.ValidationError, ToscaTemplate, tpl_path)
         exception.ExceptionCollector.assertExceptionMessage(
             exception.UnknownFieldError,
@@ -278,6 +309,15 @@ class ToscaTemplateValidationTest(TestCase):
               type: string
             default: []
         '''
+        tpl_snippet4 = '''
+        inputs:
+          some_list:
+            type: list
+            description: List of items
+            key_schema:
+              type: string
+            default: []
+        '''
         inputs1 = (toscaparser.utils.yamlparser.
                    simple_parse(tpl_snippet1)['inputs'])
         name1, attrs1 = list(inputs1.items())[0]
@@ -294,6 +334,9 @@ class ToscaTemplateValidationTest(TestCase):
         input2 = Input(name2, attrs2)
         self.assertTrue(input2.required)
         toscaparser.utils.yamlparser.simple_parse(tpl_snippet3)['inputs']
+        input4 = (toscaparser.utils.yamlparser.
+                  simple_parse(tpl_snippet4)['inputs'])
+        self.assertEqual('string', input4['some_list']['key_schema']['type'])
 
     def _imports_content_test(self, tpl_snippet, path, custom_type_def):
         imports = (toscaparser.utils.yamlparser.
@@ -306,7 +349,7 @@ class ToscaTemplateValidationTest(TestCase):
         imports:
           # omitted here for brevity
         '''
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         errormsg = _('"imports" keyname is defined without including '
                      'templates.')
         err = self.assertRaises(exception.ValidationError,
@@ -321,7 +364,7 @@ class ToscaTemplateValidationTest(TestCase):
         imports:
           - some_definitions:
         '''
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         errormsg = _('A template file name is not provided with import '
                      'definition "some_definitions".')
         err = self.assertRaises(exception.ValidationError,
@@ -329,29 +372,41 @@ class ToscaTemplateValidationTest(TestCase):
                                 tpl_snippet, path, None)
         self.assertEqual(errormsg, err.__str__())
 
-    def test_imports_without_import_name(self):
+    @mock.patch.object(urllib.request, 'urlopen')
+    def test_imports_without_import_name(self, mock_urlopen):
         tpl_snippet = '''
         imports:
           - custom_types/paypalpizzastore_nodejs_app.yaml
-          - https://raw.githubusercontent.com/openstack/\
-tosca-parser/master/toscaparser/tests/data/custom_types/wordpress.yaml
+          - https://example.com/custom_types/wordpress.yaml
         '''
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        mock_path = "https://example.com/custom_types/wordpress.yaml"
+
+        mockclass = MockTestClass()
+        mockclass.comp_urldict = {mock_path: TestCase.test_sample(
+            "data/custom_types/wordpress.yaml")}
+        mock_urlopen.side_effect = mockclass.mock_urlopen_method
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         custom_defs = self._imports_content_test(tpl_snippet,
                                                  path,
                                                  "node_types")
         self.assertTrue(custom_defs)
 
-    def test_imports_wth_import_name(self):
+    @mock.patch.object(urllib.request, 'urlopen')
+    def test_imports_wth_import_name(self, mock_urlopen):
         tpl_snippet = '''
         imports:
           - some_definitions: custom_types/paypalpizzastore_nodejs_app.yaml
           - more_definitions:
-              file: 'https://raw.githubusercontent.com/openstack/tosca-parser\
-/master/toscaparser/tests/data/custom_types/wordpress.yaml'
+              file: 'https://example.com/custom_types/wordpress.yaml'
               namespace_prefix: single_instance_wordpress
         '''
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        mock_path = "https://example.com/custom_types/wordpress.yaml"
+
+        mockclass = MockTestClass()
+        mockclass.comp_urldict = {mock_path: TestCase.test_sample(
+            "data/custom_types/wordpress.yaml")}
+        mock_urlopen.side_effect = mockclass.mock_urlopen_method
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         custom_defs = self._imports_content_test(tpl_snippet,
                                                  path,
                                                  "node_types")
@@ -365,7 +420,7 @@ tosca-parser/master/toscaparser/tests/data/custom_types/wordpress.yaml
               file: custom_types/nested_rsyslog.yaml
               namespace_prefix: testprefix
         '''
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         custom_defs = self._imports_content_test(tpl_snippet,
                                                  path,
                                                  "node_types")
@@ -385,16 +440,22 @@ tosca-parser/master/toscaparser/tests/data/custom_types/wordpress.yaml
                                 tpl_snippet, None, None)
         self.assertEqual(errormsg, err.__str__())
 
-    def test_imports_duplicate_name(self):
+    @mock.patch.object(urllib.request, 'urlopen')
+    def test_imports_duplicate_name(self, mock_urlopen):
         tpl_snippet = '''
         imports:
-          - some_definitions: https://raw.githubusercontent.com/openstack/\
-tosca-parser/master/toscaparser/tests/data/custom_types/wordpress.yaml
+          - some_definitions: https://example.com/custom_types/wordpress.yaml
           - some_definitions:
               file: my_defns/my_typesdefs_n.yaml
         '''
+        mock_path = "https://example.com/custom_types/wordpress.yaml"
+
+        mockclass = MockTestClass()
+        mockclass.comp_urldict = {mock_path: TestCase.test_sample(
+            "data/custom_types/wordpress.yaml")}
+        mock_urlopen.side_effect = mockclass.mock_urlopen_method
         errormsg = _('Duplicate import name "some_definitions" was found.')
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         err = self.assertRaises(exception.ValidationError,
                                 self._imports_content_test,
                                 tpl_snippet, path, None)
@@ -411,52 +472,71 @@ tosca-parser/master/toscaparser/tests/data/custom_types/wordpress.yaml
         '''
         errormsg = _('Import of template "more_definitions" is missing '
                      'required field "file".')
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         err = self.assertRaises(exception.MissingRequiredFieldError,
                                 self._imports_content_test,
                                 tpl_snippet, path, None)
         self.assertEqual(errormsg, err.__str__())
 
-    def test_imports_file_with_uri(self):
+    @mock.patch.object(urllib.request, 'urlopen')
+    @mock.patch.object(ToscaTemplate, '_tpl_imports')
+    def test_imports_file_with_uri(self, mock_tpl_imports, mock_urlopen):
         tpl_snippet = '''
         imports:
           - more_definitions:
-              file: https://raw.githubusercontent.com/openstack/\
-tosca-parser/master/toscaparser/tests/data/custom_types/wordpress.yaml
+              file: https://example.com/custom_types/wordpress.yaml
         '''
-        path = 'https://raw.githubusercontent.com/openstack/\
-tosca-parser/master/toscaparser/tests/data/\
-tosca_single_instance_wordpress_with_url_import.yaml'
+        path = ('https://example.com/tosca_single_instance_wordpress_'
+                'with_url_import.yaml')
+        mock_path = "https://example.com/custom_types/wordpress.yaml"
+
+        import_file_path = TestCase.test_sample(
+            "data/custom_types/wordpress.yaml")
+        mockclass = MockTestClass()
+        mockclass.comp_urldict = {mock_path: import_file_path}
+        mock_urlopen.side_effect = mockclass.mock_urlopen_method
+        mock_tpl_imports.return_value = [import_file_path]
         custom_defs = self._imports_content_test(tpl_snippet,
                                                  path,
                                                  "node_types")
         self.assertTrue(custom_defs.get("tosca.nodes."
                                         "WebApplication.WordPress"))
 
-    def test_imports_file_namespace_fields(self):
+    @mock.patch.object(urllib.request, 'urlopen')
+    def test_imports_file_namespace_fields(self, mock_urlopen):
         tpl_snippet = '''
         imports:
           - more_definitions:
-             file: https://raw.githubusercontent.com/openstack/\
-heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
+             file: https://example.com/custom_types/wordpress.yaml
              namespace_prefix: mycompany
              namespace_uri: http://docs.oasis-open.org/tosca/ns/simple/yaml/1.0
         '''
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        mock_path = "https://example.com/custom_types/wordpress.yaml"
+
+        mockclass = MockTestClass()
+        mockclass.comp_urldict = {mock_path: TestCase.test_sample(
+            "data/custom_types/wordpress.yaml")}
+        mock_urlopen.side_effect = mockclass.mock_urlopen_method
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         custom_defs = self._imports_content_test(tpl_snippet,
                                                  path,
                                                  "node_types")
         self.assertTrue(custom_defs.get("mycompany.tosca.nodes."
                                         "WebApplication.WordPress"))
 
-    def test_imports_with_local_defs(self):
+    @mock.patch.object(urllib.request, 'urlopen')
+    def test_imports_with_local_defs(self, mock_urlopen):
         """Compare custom types on local and remote."""
 
         ctypes = {
-            "remote": ("https://raw.githubusercontent.com/openstack/"
-                       "heat-translator/master/translator/tests/data/"
-                       "custom_types/wordpress.yaml"),
+            "remote": "https://example.com/custom_types/wordpress.yaml",
             "local": "../data/wordpress.yaml"}
+        mock_path = "https://example.com/custom_types/wordpress.yaml"
+
+        mockclass = MockTestClass()
+        mockclass.comp_urldict = {mock_path: TestCase.test_sample(
+            "data/custom_types/wordpress.yaml")}
+        mock_urlopen.side_effect = mockclass.mock_urlopen_method
 
         tpl_snippet = '''
         imports:
@@ -464,7 +544,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
         '''.format(ctypes["remote"])
         local_defs = {ctypes["remote"]: ctypes["local"]}
 
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         imports = (toscaparser.utils.yamlparser.
                    simple_parse(tpl_snippet)['imports'])
         ld1 = ImportsLoader(imports, path, "node_types")
@@ -476,7 +556,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
         imports:
         - custom_types/wordpress.yml
         '''
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         custom_defs = self._imports_content_test(tpl_snippet,
                                                  path,
                                                  "node_types")
@@ -492,7 +572,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
              namespace_prefix: mycompany
              namespace_uri: http://docs.oasis-open.org/tosca/ns/simple/yaml/1.0
         '''
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         self.assertRaises(ImportError,
                           self._imports_content_test,
                           tpl_snippet, path, None)
@@ -504,7 +584,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
         '''
         errormsg = _('Import "abc.com/tests/data/tosca_elk.yaml" is not '
                      'valid.')
-        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        path = TestCase.test_sample("data/tosca_elk.yaml")
         err = self.assertRaises(ImportError,
                                 self._imports_content_test,
                                 tpl_snippet, path, None)
@@ -787,9 +867,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
 
     def _custom_types(self):
         custom_types = {}
-        def_file = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "data/custom_types/wordpress.yaml")
+        def_file = TestCase.test_sample("data/custom_types/wordpress.yaml")
         custom_type = toscaparser.utils.yamlparser.load_yaml(def_file)
         node_types = custom_type['node_types']
         for name in node_types:
@@ -799,9 +877,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
 
     def _custom_types_policy(self):
         custom_types = {}
-        def_file = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "data/custom_types/custom_policy.yaml")
+        def_file = TestCase.test_sample("data/custom_types/custom_policy.yaml")
         custom_type = toscaparser.utils.yamlparser.load_yaml(def_file)
         policy_types = custom_type['policy_types']
         for name in policy_types:
@@ -1466,9 +1542,35 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
                                 rel_template.validate)
         self.assertEqual(expectedmessage, str(err))
 
+    def test_relationship_template_properties_key_schema(self):
+        tpl_path = TestCase.test_sample(
+            "data/relationship/test_custom_relationship_key_schema.yaml")
+        tosca = ToscaTemplate(tpl_path)
+        p_key_schema_type = tosca.tpl['relationship_types'][
+            'tosca.nodes.CustomRelationshipTest']['properties'][
+                'property_test']['key_schema']['type']
+        self.assertEqual('string', p_key_schema_type)
+        p_key_schema_type = tosca.relationship_templates[0].custom_def[
+            'tosca.nodes.CustomRelationshipTest']['properties'][
+                'property_test']['key_schema']['type']
+        self.assertEqual('string', p_key_schema_type)
+        property_value = (
+            tosca.topology_template.relationship_templates[0].entity_tpl[
+                'properties']['property_test']['test_key'])
+        self.assertEqual('test_value', property_value)
+
+    def test_tosca_version_1_3(self):
+        tpl_path = TestCase.test_sample(
+            "data/test_tosca_version_1_3.yaml")
+        self.assertIsNotNone(ToscaTemplate(tpl_path))
+
+    def test_import_tosca_version_1_3(self):
+        tpl_path = TestCase.test_sample(
+            "data/test_import_tosca_version_1_3.yaml")
+        self.assertIsNotNone(ToscaTemplate(tpl_path))
+
     def test_invalid_template_version(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/test_invalid_template_version.yaml")
         self.assertRaises(exception.ValidationError, ToscaTemplate, tosca_tpl)
         valid_versions = '", "'.join(ToscaTemplate.VALID_TEMPLATE_VERSIONS)
@@ -1478,8 +1580,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
                'are "%s".') % valid_versions))
 
     def test_import_invalid_template_version(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tosca_tpl = TestCase.test_sample(
             "data/test_import_invalid_template_version.yaml")
         self.assertRaises(exception.ValidationError, ToscaTemplate, tosca_tpl)
         valid_versions = '", "'.join(ToscaTemplate.VALID_TEMPLATE_VERSIONS)
@@ -1490,9 +1591,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
                ' is invalid. Valid versions are "%s".') % valid_versions))
 
     def test_import_template_metadata(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "data/test_import_metadata.yml")
+        tosca_tpl = TestCase.test_sample("data/test_import_metadata.yml")
         ToscaTemplate(tosca_tpl)
 
     def test_node_template_capabilities_properties(self):
@@ -1676,6 +1775,39 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
         name = list(triggers.keys())[0]
         Triggers(name, triggers[name])
 
+    # Since the keyname 'event_type' has been changed in TOSCA1.3,
+    # test whether the new keyname 'event' can be used.
+    def test_policy_trigger_keyname_event(self):
+        tpl_snippet = '''
+        triggers:
+         - resize_compute:
+             description: trigger
+             event: tosca.events.resource.utilization
+             schedule:
+               start_time: "2015-05-07T07:00:00Z"
+               end_time: "2015-06-07T07:00:00Z"
+             target_filter:
+               node: master-container
+               requirement: host
+               capability: Container
+             condition:
+               constraint: { greater_than: 50 }
+               granularity: 60
+               evaluations: 1
+               aggregation_method : mean
+             action:
+               resize: # Operation name
+                inputs:
+                 strategy: LEAST_USED
+                 implementation: Senlin.webhook()
+        '''
+        triggers = (toscaparser.utils.yamlparser.
+                    simple_parse(tpl_snippet))['triggers'][0]
+        name = list(triggers.keys())[0]
+        trigger = Triggers(name, triggers[name])
+        self.assertEqual('tosca.events.resource.utilization',
+                         trigger.get_event())
+
     def test_policy_trigger_valid_keyname_heat_resources(self):
         tpl_snippet = '''
         triggers:
@@ -1802,14 +1934,11 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
         self.assertEqual(expectedmessage, err.__str__())
 
     def test_credential_datatype(self):
-        tosca_tpl = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "data/test_credential_datatype.yaml")
+        tosca_tpl = TestCase.test_sample("data/test_credential_datatype.yaml")
         self.assertIsNotNone(ToscaTemplate(tosca_tpl))
 
     def test_invalid_default_value(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/test_invalid_input_defaults.yaml")
         self.assertRaises(exception.ValidationError, ToscaTemplate, tpl_path)
         exception.ExceptionCollector.assertExceptionMessage(
@@ -1916,15 +2045,12 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
             self._single_node_template_content_test(tpl_snippet3))
 
     def test_properties_override_with_flavor_and_image(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/test_normative_type_properties_override.yaml")
         self.assertIsNotNone(ToscaTemplate(tpl_path))
 
     def test_long_rel(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "data/test_long_rel.yaml")
+        tpl_path = TestCase.test_sample("data/test_long_rel.yaml")
         self.assertIsNotNone(ToscaTemplate(tpl_path))
 
     def test_policy_reservation_valid_keyname_heat_resources(self):
@@ -1978,8 +2104,7 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
         self.assertEqual(expectedmessage, err.__str__())
 
     def test_scalar_unit_without_unit(self):
-        tpl_path = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
+        tpl_path = TestCase.test_sample(
             "data/test_scalar_unit_without_unit.yaml")
         self.assertRaises(exception.ValidationError,
                           lambda: ToscaTemplate(tpl_path))
